-- Copyright 1995-2000 Tom Moran, may be used by anyone for any purpose.

with Ada.Numerics;
generic
  N:natural;  -- principal quantum number
  L:natural;  -- angular momentum quantum number, spdfg range 0 .. N-1
  S:integer;  -- magnetic quantum number, range -L .. L
  -- 1s => N=1, L=0, S=0    2p-1 => N=2, L=1, S= -1   etc
package Hydrogen_Atom is

  m_e:constant float:=9.11E-28;   -- mass of electron (grams)
  h:constant float:=6.6E-27;      -- Planck's constant (erg sec)
  c_e:constant float:=4.8E-10;    -- charge of electron (esu)

  a0:constant float   -- Bohr 1S radius = 0.529 Angstrom
    :=(h/(Ada.Numerics.pi*c_e))**2
      /(4.0*m_e);

  function Radial(R : float) return float;

  function Angular(Theta : float) return float;
  -- Note: Theta=0 is the North pole, Theta=pi the South pole.

end Hydrogen_Atom;
